@@ -1,7 +1,7 @@
 import os,sys
 from io import StringIO
 class csv2cleartable:
-    def printtable(message):
+    def printtable(self,message):
         #finalmessage=""
         #finalmessage=finalmessage +
         term_size = os.get_terminal_size()
